# is_hex()

## How to use

1. ```python
   from colorcodetools.hex.validate import is_hex
   is_hex('hexcode')
   ```
2. ```python
   import colorcodetools
   colorcodetools.hex.validate.is_hex('hexcode')
   ```

## Parameters

1. Required parameters:

   - hexcode:  
      Enter hex code which should be checked.
     - `type: string`
     - `default: None`
     - `example: #f0f0f0`

## Return value

- `type: boolean`
